jenkins-repo Cookbook
====================
[![Build Status](https://travis-ci.org/st-isidore-de-seville/cookbook-jenkins-repo.svg?branch=master)](https://travis-ci.org/st-isidore-de-seville/cookbook-jenkins-repo)
[![Chef Cookbook](https://img.shields.io/cookbook/v/jenkins-repo.svg)](https://supermarket.chef.io/cookbooks/jenkins-repo)

Configures Jenkins Vendor-Specific Repositories.

This cookbook configures Jenkins repositories per https://jenkins-ci.org for apt
and yum.

Requirements
------------
- Chef 11 or higher
- Ruby 1.9 or higher (preferably from the Chef full-stack installer)
- Network accessible package repositories

Attributes
----------
#### jenkins-repo::default
The default cookbook manages repository settings for the Jenkins Long-Term
Support (LTS) release line and Jenkins newer weekly releases.  Jenkins LTS
packages are considered part of the "jenkins-stable" repository and Jenkins
weekly releases are considered part of the "jenkins-mainline" repository.
"jenkins-stable" is managed by default.

- `['jenkins-repo']['jenkins-stable']['managed']`
  - _Type:_: Boolean
  - _Description:_ Does this cookbook manage the install of the jenkins-stable
    repo?
  - _Default:_ `true`
- `['jenkins-repo']['jenkins-mainline']['managed']`
  - _Type:_ Boolean
  - _Description:_ Does this cookbook manage the install of the jenkins-mainline
    repo?
  - _Default:_: `false`

#### jenkins-repo::_apt
The apt recipe is for managing the Jenkins apt repostories.  Any attribute
supported by the [apt cookbook](https://github.com/opscode-cookbooks/apt#attribute-parameters)
is supported by this cookbook and can be used to override attributes in this
cookbook.

- `['jenkins-repo']['jenkins-stable']['apt']['uri']`
  - _Type:_ String
  - _Description:_ URI of Jenkins Stable Repo
  - _Default:_ `http://pkg.jenkins-ci.org/debian-stable`
- `['jenkins-repo']['jenkins-stable']['apt']['components']`
  - _Type:_ Array
  - _Description:_ Jenkins Stable Repo Package Groupings
  - _Default:_ `['binary/']`
- `['jenkins-repo']['jenkins-stable']['apt']['key']`
  - _Type:_ String
  - _Description:_ Cookbook File for Jenkins Stable Repo Signing Key`
  - _Default:_ `jenkins-ci.org.key`
- `['jenkins-repo']['jenkins-stable']['apt']['deb-src']
  - _Type:_ Boolean
  - _Description:_ Whether or not to include the jenkins-stable source repo?
  - _Default:_ `false`
- `['jenkins-repo']['jenkins-mainline']['apt']['uri']`
  - _Type:_ String
  - _Description:_ URI of Jenkins Mainline Repo
  - _Default:_ `http://pkg.jenkins-ci.org/debian`
- `['jenkins-repo']['jenkins-mainline']['apt']['components']`
  - _Type:_ Array
  - _Description:_ Jenkins Mainline Repo Package Groupings
  - _Default:_ `['binary/']`
- `['jenkins-repo']['jenkins-mainline']['apt']['key']`
  - _Type:_ String
  - _Description:_ Cookbook File for Jenkins Mainline Repo Signing Key
  - _Default:_ `jenkins-ci.org.key`
- `['jenkins-repo']['jenkins-mainline']['apt']['deb-src']`
  - _Type:_ Boolean
  - _Description:_ Whether or not to include the jenkins-mainline source repo?
  - _Default:_ `false`

#### jenkins-repo::_yum
The yum recipe is for managing the Jenkins yum repostories.  Any attribute
supported by the [yum cookbook](https://github.com/chef-cookbooks/yum#parameters)
is supported by this cookbook and can be used to override attributes in this
cookbook.

- `['jenkins-repo']['jenkins-stable']['yum']['repositoryid']`
  - _Type:_ String
  - _Description:_ Unique Name for Jenkins Stable Repo
  - _Default:_ `jenkins-stable`
- `['jenkins-repo']['jenkins-stable']['yum']['description']`
  - _Type:_ String
  - _Description:_ Description of Jenkins Stable Repo
  - _Default:_ `Jenkins Stable`
- `['jenkins-repo']['jenkins-stable']['yum']['baseurl']`
  - _Type:_ String
  - _Description:_ URL of Jenkins Stable Repo
  - _Default:_ `http://pkg.jenkins-ci.org/redhat-stable`
- `['jenkins-repo']['jenkins-stable']['yum']['gpgcheck']`
  - _Type:_ Boolean
  - _Description:_ Whether or not Jenkins Stable Repo should perform GPG check of packages?
  - _Default:_ `true`
- `['jenkins-repo']['jenkins-stable']['yum']['gpgkey']`
  - _Type:_ String
  - _Description:_ GPG Key Used for Verifying Jenkins Stable Repo Packages
  - _Default:_ `file:///etc/pki/rpm-gpg/RPM-GPG-KEY-Jenkins`
- `['jenkins-repo']['jenkins-stable']['yum']['sslverify']`
  - _Type:_ Boolean
  - _Description:_ Whether or not yum will verify the Jenkins Stable Repo SSL host?
  - _Default:_ `false`
- `['jenkins-repo']['jenkins-stable']['yum']['enabled']`
  - _Type:_ Boolean
  - _Description:_ Whether or not the Jenkins Stable Repo is enabled?
  - _Default:_ `true`
- `['jenkins-repo']['jenkins-mainline']['yum']['repositoryid']`
  - _Type:_ String
  - _Description:_ Unique Name for Jenkins Mainline Repo
  - _Default:_ `jenkins-mainline`
- `['jenkins-repo']['jenkins-mainline']['yum']['description']`
  - _Type:_ String
  - _Description:_ Description for Jenkins Mainline Repo
  - _Default:_ `Jenkins Mainline`
- `['jenkins-repo']['jenkins-mainline']['yum']['baseurl']`
  - _Type:_ String
  - _Description:_ URL of Jenkins Mainline Repo
  - _Default:_ `http://pkg.jenkins-ci.org/redhat`
- `['jenkins-repo']['jenkins-mainline']['yum']['gpgcheck']`
  - _Type:_ Boolean
  - _Description:_ Whether or not Jenkins Mainline Repo should perform GPG check of packages?
  - _Default:_ `true`
- `['jenkins-repo']['jenkins-mainline']['yum']['gpgkey']`
  - _Type:_ String
  - _Description:_ GPG Key Used for Verifying Jenkins Mainline Repo Packages
  - _Default:_ `file:///etc/pki/rpm-gpg/RPM-GPG-KEY-Jenkins`
- `['jenkins-repo']['jenkins-mainline']['yum']['sslverify']`
  - _Type:_ Boolean
  - _Description:_ Whether or not yum will verify the Jenkins Mainline Repo SSL host?
  - _Default:_ `false`
- `['jenkins-repo']['jenkins-mainline']['yum']['enabled']`
  - _Type:_ Boolean
  - _Description:_ Whether or not the Jenkins Mainline Repo is enabled?
  - _Default:_ `true`

Usage
-----
#### jenkins-repo::default
Just include `jenkins-repo` in your node's `run_list`:

```json
{
  "name":"my_node",
  "run_list": [
    "recipe[jenkins-repo]"
  ]
}
```

Contributing
------------
1. Fork the repository on GitHub
2. Create a named feature branch (like `add_component_x`)
3. Write your change
4. Write tests for your change (if applicable)
5. Run the tests, ensuring they all pass
6. Submit a Pull Request using GitHub

Development Environment
-------------------
This repository contains a Vagrantfile which can be used to spin up a
fully configured development environment in Vagrant.  

Vagrant requires the following:
- [VirtualBox](https://www.virtualbox.org/)
- [Vagrant](https://www.vagrantup.com/)

The Vagrant environment for this repository is based on:
- [st-isidore-de-seville/trusty64-rvm-docker](https://atlas.hashicorp.com/st-isidore-de-seville/boxes/trusty64-rvm-docker)

The Vagrant environment will initialize itself to:
- install required Ruby gems
- run integration testing via kitchen-docker when calling `kitchen`

The Vagrant environment can be spun up by performing the following commands:

1. `vagrant up`
2. `vagrant ssh`
3. `cd /vagrant`

Authors
-------------------
- Author:: St. Isidore de Seville (st.isidore.de.seville@gmail.com)

License
-------------------
```text
The MIT License (MIT)

Copyright (c) 2015 St. Isidore de Seville (st.isidore.de.seville@gmail.com)

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
```
