node['jenkins-repo'].each do |repo, value|
  yum_repository repo do
    yum = value['yum']

    # define all attributes even though we are not using them all so that the values
    #  can be passed through to override yum repository definitions

    # Attribute Sources:
    #  https://github.com/chef-cookbooks/yum
    #  https://github.com/chef-cookbooks/yum/blob/master/resources/repository.rb

    baseurl yum['baseurl']
    cost yum['cost']
    description yum['description']
    enabled yum['enabled']
    enablegroups yum['enablegroups']
    exclude yum['exclude']
    failovermethod yum['failovermethod']
    fastestmirror_enabled yum['fastestmirror_enabled']
    gpgcheck yum['gpgcheck']
    gpgkey yum['gpgkey']
    http_caching yum['http_caching']
    includepkgs yum['includepkgs']
    keepalive yum['keepalive']
    make_cache yum['make_cache']
    max_retries yum['max_retries']
    metadata_expire yum['metadata_expire']
    mirror_expire yum['mirror_expire']
    mirrorlist yum['mirrorlist']
    mirrorlist_expire yum['mirrorlist_expire']
    mode yum['mode']
    options yum['options']
    password yum['password']
    priority yum['priority']
    proxy yum['proxy']
    proxy_username yum['proxy_username']
    proxy_password yum['proxy_password']
    report_instanceid yum['report_instanceid']
    repositoryid yum['repositoryid']
    skip_if_unavailable yum['skip_if_unavailable']
    source yum['source']
    sslcacert yum['sslcacert']
    sslclientcert yum['sslclientcert']
    sslclientkey yum['sslclientkey']
    sslverify yum['sslverify']
    timeout yum['timeout']
    username yum['username']
  end if value['managed'] && value.key?('yum')
end

cookbook_file 'create Jenkins GPG key' do
  path '/etc/pki/rpm-gpg/RPM-GPG-KEY-Jenkins'
  source 'jenkins-ci.org.key'
  owner 'root'
  group 'root'
  mode '0644'

  notifies :run, 'execute[import Jenkins GPG key]', :immediately
end

# http://dan.carley.co/blog/2012/05/22/yum-gpg-keys-for-jenkins/
execute 'import Jenkins GPG key' do
  command 'rpm --import /etc/pki/rpm-gpg/RPM-GPG-KEY-Jenkins'
  action :nothing
  only_if { platform_family?('rhel') && node['platform_version'].to_i < 6 }
end
